MySQL备份之mysqldump
admin
2023-04-16 16:01:50
0次

mysqldump是mysql自带的数据库备份工具,属于单线程,大部分生产环境的mysql数据库备份都是使用该工具,mysqldump可以将数据导出为原生sql语句,在将其数据导入至数据库时,相当于是执行一遍备份文件中的所有sql语句,

mysqldump提供了丰富的options选项,可以在导出或者导入数据的时候,添加需要的options,以便达到用户预期的效果

MySQL备份之mysqldump

mysql常用参数

// 导出全部数据库。
// --all-databases , -A
mysqldump -uroot -p --all-databases

// 导出全部表空间。
// --all-tablespaces , -Y
mysqldump -uroot -p --all-databases --all-tablespaces

// 不导出任何表空间。
// --no-tablespaces , -y
mysqldump -uroot -p --all-databases --no-tablespaces

// 导出几个数据库。参数后面所有名字参量都被看作数据库名。
// --databases, -B
mysqldump -uroot -p --databases [数据库名1] [数据库名2]

// 每个数据库创建之前先添加drop数据库语句(如有原库则先drop后再重新create)。
// --add-drop-database
mysqldump -uroot -p --all-databases --add-drop-databas

// 每个数据表创建之前先添加drop数据表语句。(默认为打开状态,使用--skip-add-drop-table取消选项)。
// --add-drop-table
mysqldump -uroot -p --all-databases (默认添加drop语句)
mysqldump -uroot -p --all-databases –skip-add-drop-table (取消drop语句)

// 设置默认字符集,默认值为utf8。
// --default-character-set
mysqldump -uroot -p --all-databases --default-character-set=latin1

// 使用十六进制格式导出二进制字符串字段。如果有二进制数据就必须使用该选项。影响到的字段类型有BINARY、VARBINARY、BLOB。
// --hex-blob
mysqldump -uroot -p --all-databases --hex-blob

// 使用具有多个VALUES列的INSERT语法。这样使导出文件更小,并加速导入时的速度。默认为打开状态,使用--skip-extended-insert取消选项。
// --extended-insert, -e
mysqldump -uroot -p --all-databases
mysqldump -uroot -p --all-databases --skip-extended-insert (取消选项)

// 使用完整的insert语句(包含列名称)。这么做能提高插入效率,但是可能会受到max_allowed_packet参数的影响而导致插入失败。
// --complete-insert, -c
mysqldump -uroot -p --all-databases --complete-insert

// 不缓冲查询,直接导出到标准输出。默认为打开状态,使用--skip-quick取消该选项。
// --quick, -q
mysqldump -uroot -p --all-databases
mysqldump -uroot -p --all-databases --skip-quick

// 该选项在导出数据之前提交一个BEGIN SQL语句,BEGIN 不会阻塞任何应用程序且能保证导出时数据库的一致性状态。
// 它只适用于多版本存储引擎,仅InnoDB。本选项和--lock-tables 选项是互斥的,因为LOCK TABLES 会使任何挂起的事务隐含提交。
// 要想导出大表的话,应结合使用--quick 选项。
// --single-transaction
mysqldump -uroot -p --all-databases --single-transaction

// 不导出指定的表。指定忽略多个表时,需要重复多次,每次一个表。每个表必须同时指定数据库和表名。
// --ignore-table
例如:--ignore-table=database.table1 --ignore-table=database.table2 ……
mysqldump -uroot -p  --all-databases --ignore-table=mysql.user

2、生产中常用的参数
注意:下面每个场景都会列出多个命令,读者根据生产的情况来参考

1.导出单库

  • 格式:mysqldump -uroot -p [数据库名]
mysqldump -uroot -p  [数据库名] >/backup/[导出的文件名].sql.gz
mysqldump -uroot -p  [数据库名] --single-transaction >/backup/[导出的文件名].sql.gz
mysqldump -uroot -p  [数据库名]  --default-character-set=utf8 --set-gtid-purged=OFF --single-transaction >/backup/[导出的文件名].sql.gz

2.导出多个库

  • 格式:mysqldump -uroot -p -B [数据库名1] [数据库名2]
    mysqldump -uroot -p  -B [数据库名1] [数据库名2] >/backup/[导出的文件名].sql.gz
    mysqldump -uroot -p  -B [数据库名1] [数据库名2] --single-transaction >/backup/[导出的文件名].sql.gz
    mysqldump -uroot -p -B [数据库名1] [数据库名2] --default-character-set=utf8 --set-gtid-purged=OFF --single-transaction >/backup/[导出的文件名].sql.gz

3.导出单个表

  • 格式:mysqldump -uroot -p [数据库名] [表名]
mysqldump -uroot -p  [数据库名] [表名] >/backup/[导出的文件名].sql.gz
mysqldump -uroot -p  [数据库名] [表名] --single-transaction >/backup/[导出的文件名].sql.gz
mysqldump -uroot -p  [数据库名] [表名]  --default-character-set=utf8 --set-gtid-purged=OFF --single-transaction >/backup/[导出的文件名].sql.gz

4.导出多个表

  • 格式:mysqldump -uroot -p [数据库名] [表名1] [表名2]
mysqldump -uroot -p  [数据库名] [表名1] [表名2] >/backup/[导出的文件名].sql.gz
mysqldump -uroot -p  [数据库名] [表名1] [表名2] --single-transaction >/backup/[导出的文件名].sql.gz
mysqldump -uroot -p [数据库名] [表名1] [表名2] --default-character-set=utf8 --set-gtid-purged=OFF --single-transaction >/backup/[导出的文件名].sql.gz

5.导入和导出大表

mysqldump -uroot -p --default-character-set=utf8 --quick \
--extended-insert --single-transaction [数据库名] |gzip >/backup/[导出的文件名].sql.gz

gzip按照需求来定,主要是对导出的sql数据的压缩

6.过滤库中的表后在导出

mysqldump -uroot -p --ignore-table=[数据库名.表名1] --ignore-table=[数据库名.表名2] >/backup/[导出的文件名].sql.gz

在过滤库中的表后导出的数据的时候,是不需要单独指定库名的,只需要把需要过滤的库下对应的表填上,它就会自动的把那些填上库对应的表给过滤,将那些没有被过滤的表中的数据导出到指定文件中

上一篇:主从搭建

下一篇:Oracle12.2 ORA-03113

相关内容

热门资讯

空调连续工作多久需要停机休息 空调连续工作的时间取决于多个因素,包括空调的型号、功率、使用环境和维护情况等。一般来说,空调可以连续...
空调哪个符号是除湿的 空调除湿功能通常用一个水滴形状的符号表示。不同品牌和型号的空调遥控器可能会有所差异,但一般来说,除湿...
格力空调多长时间加一次氟利昂 1、一般情况下,空调对氟利昂的使用量是非常小的,所以在空调使用了四年左右的时候再考虑加也没问题。2、...
空调用多长时间需要加氟一次 一般情况下是五年。当出现以下这几种情况时,空调才需要加氟。1、空调的室内机和室外机各有两个接口,当接...
格调生活·C标思享荟:卡萨帝在... 9月12日的郑州龙湖金融岛,夜风轻拂,灯光璀璨。“C标时刻共传奇——卡萨帝思享荟暨20周年品牌盛典郑...
品牌价值破千亿、高端份额持续领... 9月12日,“C标时刻共传奇——卡萨帝思享荟暨20周年品牌盛典郑州站”在郑州龙湖金融岛举办。2026...
空调主板坏了修800还是换新的 空调主板坏了是修还是换新,需要考虑多个因素,以下是一些建议:1. 维修成本:如果维修费用较低,比如 ...
空调开多久需要休息多长时间 问题:空调开多久需要休息多长时间回答:1、在使用空调的过程中,一般空调开7~8个小时左右需要休息2~...
中央空调多长时间清洗一次 1、一般空调开机前清洗一次即可,空调开机中间时段再清洗一次,空调关机时清洗一次,这样比较合理。2、空...
中央空调氟利昂多久加一次 看空调制热和制冷程度,很多人的观点认为氟利昂必须一年放一次,其实这个观点是错误的,理解上面有点偏差,...